/**
 * Sort objects by object properties
 */
export declare function sortBy<T>(arr: T[], keys: Array<keyof T>): T[];
/**
 * Take out the first N items of an array
 */
export declare function take<T>(arr: T[], n: number): T[];
/**
 * Get the first element of an array
 */
export declare function head<T>(arr: T[]): T | undefined;
/**
 * Get multiple object or array value by paths. Example path: `a[0].b.c`
 */
export declare function at(source: Record<string, unknown> | any[], paths: string[] | string): any[];
/**
 * Return item by path or default value if not present
 */
export declare function get<T = any>(source: Record<string, unknown> | any[], path: string | Array<string | number>, defaultValue?: T): T | undefined;
/**
 * Check if an item is in an object by path
 */
export declare function has(source: Record<string, unknown> | any[], path: string | Array<string | number>): boolean;
/**
 * Check if a collection (Array, Map, Set, Object) is empty
 */
export declare function isEmpty(v: any): boolean;
/**
 * Pick values out of an object by predicate and return them in a new object
 */
export declare function pickBy<T extends Record<string, unknown>>(obj: T, predicate: <K extends keyof T>(value: T[K], key: K) => boolean): Partial<T>;
/**
 * Loop over a collection and call the callback on each item
 */
export declare function forEach<T>(value: T, callback: (value: any, index: number | string, collection: T) => void): void;
/**
 * Convert string to kebab case
 */
export declare function kebabCase(input: string): string;
/**
 * Get index of an item in an array
 */
export declare function indexOf<T>(arr: T[], value: T, startIndex?: number): number;
/**
 * Flatten an array by a single level
 */
export declare function flatten(arr: any[]): any[];
/**
 * Remove falsy values from array
 */
export declare function compact(arr: unknown[]): unknown[];
/**
 * Generates a unique ID
 */
export declare function uniqueId(prefix?: string): string;
export declare function once<T extends (...args: any[]) => any>(fn: T): T;
/**
 * Create a duplicate free version of an array by a user iteratee
 */
export declare function uniqBy<T, R = any>(arr: T[], iteratee: R | ((v: T) => R)): T[];
export declare type AnyFunction = (...args: any[]) => any;
/**
 * Pass the result of the first function to the next one.
 */
export declare function flow(...fns: AnyFunction[]): (this: any, ...args: any[]) => any;
/**
 * Shallow clone of a value
 */
export declare function clone<T>(value: T): T;
/**
 * Deeply clone a value
 */
export declare function cloneDeep<T>(value: T): T;
/**
 * Deeply merge multiple objects
 */
export declare function merge(...objs: Record<string, any>[]): Record<string, any>;
/**
 * Iterate the collection and return the element where the predicate returns true
 */
export declare function find<T>(collection: T[], predicate?: string | [string, any] | Record<string, any> | ((item: T) => boolean), fromIndex?: number): T | undefined;
/**
 * Shallowly compare to values
 */
export declare function isEqual<T>(a: T, b: T): boolean;
